###############
Component class
###############

.. |br| raw:: html

   <br />

The Component class holds the basic data of a component and provides functions for adding the component to an
EnergySystemModel class instance and clustering and specifying time series data. The ComponentModel class on
the other hand specifies basic sets, variables, constraints and output functions for a collection of components.

**Component class description:**

.. automodule:: component
.. autoclass:: Component
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: Component
   :parts: 1

|

**ComponentModel class description:**

.. autoclass:: ComponentModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: ComponentModel
   :parts: 1